@@ -2,7 +2,7 @@ package Acme::MetaSyntactic::linux;
 use strict;
 use Acme::MetaSyntactic::List;
 our @ISA = qw( Acme::MetaSyntactic::List );
-our $VERSION = '1.029';
+our $VERSION = '1.030';
 
 our %Remote = (
     source  => 'http://distrowatch.com/',
@@ -16,6 +16,7 @@ our %Remote = (
                 $_
                 }
             map { Acme::MetaSyntactic::RemoteList::tr_nonword($_) }
+            map { Acme::MetaSyntactic::RemoteList::tr_accent($_) }
             map { Acme::MetaSyntactic::RemoteList::tr_utf8_basic($_) }
             $forms[0] =~ m!<option value=".*?">([^<]+?)</option>!g;
     }
@@ -47,6 +48,12 @@ Philippe Bruhat (BooK).
 
 =item *
 
+2016-03-21 - v1.030
+
+Updated from the source web site in Acme-MetaSyntactic-Themes version 1.049.
+
+=item *
+
 2015-10-19 - v1.029
 
 Updated from the source web site in Acme-MetaSyntactic-Themes version 1.048.
@@ -274,6 +281,8 @@ ZeroLinux
 TwoXOS
 FourMLinux
 Absolute
+AbulEdu
+AgiliaLinux
 Alpine
 ALT
 Android_x86
@@ -282,7 +291,6 @@ antiX
 APODIO
 Arch
 ArchBang
-ArtistX
 AsteriskNOW
 AUSTRUMI
 AV_Linux
@@ -290,7 +298,6 @@ BackBox
 Baltix
 Bardinux
 Baruwa
-Bella
 Berry
 Bicom
 Bio_Linux
@@ -302,24 +309,23 @@ BlankOn
 Bodhi
 BOSS
 Bridge
-CAELinux
+BSDRP
 CAINE
-Caixa_M_gica
+Caixa_Magica
 Calculate
 Canaima
-C_tix
 CentOS
 Centrych
 Chakra
 ChaletOS
 Chapeau
 Chitwanix
-Chromixium
 ClearOS
 Clonezilla
 Connochaet
 CoreOS
 CRUX
+Cub
 Debian
 deepin
 DEFT
@@ -330,11 +336,12 @@ Edubuntu
 Elastix
 elementary
 Elive
-Emmabunt_s
+Emmabuntus
 Endian
 Exe
 Exherbo
 ExTiX
+eZeY
 Fedora
 Fermi
 Finnix
@@ -343,15 +350,14 @@ FreeNAS
 Frugalware
 FuguIta
 Funtoo
-GeeXboX
 Gentoo
 GhostBSD
-gNewSense
 GoboLinux
 GParted
 Greenie
 Grml
 Guadalinex
+GuixSD
 Haiku
 HandyLinux
 Hanthana
@@ -378,7 +384,6 @@ Linpus
 LinuxBBQ
 LinuxConsole
 Linuxfx
-Liquid_Lemur
 Lite
 LliureX
 LPS
@@ -391,15 +396,14 @@ Mageia
 MakuluLinux
 Mangaka
 Manjaro
-Matriux
 MAX
+Metamorphose
 MidnightBSD
 MiniNo
 MINIX
 Mint
 Miracle
 MirOS
-Momonga
 Musix
 Mythbuntu
 Nanolinux
@@ -408,13 +412,10 @@ Neptune
 NetBSD
 NethServer
 Netrunner
-NetSecL
 NexentaStor
 NixOS
-Nova
 NST
 NuTyX
-Ojuba
 OLPC
 Omoikane
 OpenBSD
@@ -426,7 +427,6 @@ OpenMandriva
 OpenMediaVault
 openSUSE
 Openwall
-Open_Xange
 OPNsense
 Oracle
 OSMC
@@ -435,7 +435,7 @@ Oz_Unity
 paldo
 Parabola
 Pardus
-Parrot_Security_OS
+Parrot
 Parsix
 Parted_Magic
 PC_BSD
@@ -462,6 +462,7 @@ Qubes
 Quirky
 Raspbian
 ReactOS
+RebeccaBlackOS
 Rebellin
 Red_Hat
 REMnux
@@ -523,12 +524,13 @@ Ubuntu_Studio
 UHU_Linux
 Ulteo
 Ultimate
-Unity
 Univention
 Untangle
 UPR
+URIX
 Vector
 Vine
+Vinux
 Void
 Volumio
 VortexBox
@@ -536,6 +538,7 @@ Voyager
 VyOS
 wattOS
 Webconverger
+Whonix
 Wifislax
 WM_Live
 XStreamOS
