@@ -20,13 +20,35 @@ Characters from the Magic Round About children television series.
 
 Cdric Bouvier, C<< <cbouvi@cpan.org> >>.
 
-Introduced in Acme-MetaSyntactic version 0.24, published on May 30, 2005.
+=head1 CHANGES
 
-Received its own version number for Acme-MetaSyntactic-Themes version 1.000,
-published on May 7, 2012.
+=over 4
 
-Updated with an C<=encoding> pod command in version 1.001,
-published on May 14,2012
+=item *
+
+2012-05-14 - v1.001
+
+Updated with an C<=encoding> pod command in version 1.001.
+
+=item *
+
+2012-05-07 - v1.000
+
+Received its own version number in Acme-MetaSyntactic-Themes version 1.000.
+
+=item *
+
+2005-05-30
+
+Introduced in Acme-MetaSyntactic version 0.24.
+
+=item *
+
+2005-04-06
+
+Submitted by Cdric Bouvier.
+
+=back
 
 =head1 SEE ALSO
 
