@@ -2,7 +2,7 @@ package Acme::MetaSyntactic::pokemon;
 use strict;
 use Acme::MetaSyntactic::List;
 our @ISA = qw( Acme::MetaSyntactic::List );
-our $VERSION = '1.006';
+our $VERSION = '1.007';
 __PACKAGE__->init();
 
 our %Remote = (
@@ -28,7 +28,7 @@ Acme::MetaSyntactic::pokemon - The Pokmon theme
 
 =head1 DESCRIPTION
 
-List of the 719 Pokmon characters that are officially known to exist
+List of the 722 Pokmon characters that are officially known to exist
 in the franchise.
 
 This list is based on the following wikipedia article:
@@ -48,6 +48,13 @@ Abigail, Philippe Bruhat (BooK)
 
 =item *
 
+2016-03-21 - v1.007
+
+Updated with "The Mythical Pokmons" Volcanion and Magearna
+in Acme-MetaSyntactic-Themes version 1.049.
+
+=item *
+
 2015-02-02 - v1.006
 
 Updated with "The Mythical Pokmon Hoopa"
@@ -867,3 +874,5 @@ Yveltal
 Zygarde
 Diancie
 Hoopa
+Volcanion
+Magearna
