@@ -2,7 +2,7 @@ package Acme::MetaSyntactic::tour_de_france;
 use strict;
 use Acme::MetaSyntactic::List;
 our @ISA = qw( Acme::MetaSyntactic::List );
-our $VERSION = '1.005';
+our $VERSION = '1.006';
 
 =encoding iso-8859-1
 
@@ -31,6 +31,8 @@ The winners from 1903 onwards are:
 
 =pod
 
+    2015   Chris Froome          GBR
+    2014   Vincenzo Nibali       ITA
     2013   Chris Froome          GBR
     2012   Bradley Wiggins       GBR
     2011   Cadel Evans           AUS
@@ -154,6 +156,13 @@ Abigail
 
 =item *
 
+2015-08-10 - v1.006
+
+Updated with the winners of the 2014 and 2015 editions,
+published in Acme-MetaSyntactic-Themes version 1.047.
+
+=item *
+
 2013-07-29 - v1.005
 
 Spelling fixes sent by Abigail,
